@@ -22,8 +22,6 @@ public: // No need for protected or private
 
     std::string lib_str;            // multi argument parameters for library
     std::string pred_str;           // multi argument parameters for prediction
-    bool        disjointLibrary;    // breaks in lib?
-    std::vector< size_t > disjointLibraryRows; // disjoint rows not in library
 
     std::vector<size_t> library;    // library row indices
     std::vector<size_t> prediction; // prediction row indices
